@@ -7,33 +7,56 @@ from formerbox.cli import ConvertDataset, Preprocess, Subcommand, Train, TrainTo
 from formerbox.common import (
     DataclassArgumentParser,
     DataclassBase,
+    FromPartial,
     HasParams,
     HasParsableParams,
-    PartialInitable,
     Registrable,
 )
 from formerbox.data import (
+    BartTokenizer,
+    BartTokenizerTrainer,
     Binarizer,
     DatasetConverter,
+    DatasetIterator,
+    DefaultBinarizer,
+    DefaultDatasetConverter,
+    GPT2Tokenizer,
+    GPT2TokenizerTrainer,
     IndexedCachedDataset,
     IndexedDataset,
     IndexedDatasetBuilder,
     MMapIndexedDataset,
     MMapIndexedDatasetBuilder,
-    TransformerBinarizer,
-    TransformerDatasetConverter,
+    RobertaTokenizer,
+    RobertaTokenizerTrainer,
+    TokenizerBase,
+    TokenizerTrainerBase,
+    TranslationBinarizer,
+    TranslationDataset,
+)
+from formerbox.modules import (
+    DenoisingDataModule,
+    DenoisingModule,
+    MaskedLMDataModule,
+    MaskedLMModule,
+    TokenizerTrainer,
+    TransformerDataModule,
+    TransformerModule,
+    TranslationDataModule,
+    TranslationModule,
+    WordLMDataModule,
+    WordLMModule,
 )
-from formerbox.modules import TokenizerModule, TransformerDataModule, TransformerModule
 from formerbox.optim import AdamW, get_polynomial_decay_with_warmup, weight_decay_params
 from formerbox.tasks import (
-    ByteLevelBPETokenizerFast,
-    ByteLevelBPETokenizerModule,
-    CodeBBPETokenizerFast,
-    CodeBBPETokenizerModule,
     CodeDatasetConverter,
+    CodeRobertaTokenizer,
+    CodeRobertaTokenizerTrainer,
+    DenoisingTask,
+    MaskedLMTask,
     TaskModule,
-    TransformerTask,
-    TransformerTokenizerModule,
+    TranslationTask,
+    WordLMTask,
 )
 from formerbox.training import TransformerTrainer
 
