@@ -22,13 +22,19 @@ from typing_inspect import (
     is_union_type,
 )
 
-T = typing.TypeVar("T")  # pylint: disable=invalid-name
+MISSING: Any = "???"
+
+ParamsType = typing.TypeVar("ParamsType")
 DataclassBaseType = Type["DataclassBase"]
 DataclassTypes = Union[DataclassBaseType, typing.Iterable[DataclassBaseType]]
 
 logger = logging.getLogger(__name__)
 
 
+def is_missing(obj: Any) -> bool:
+    return obj is dataclasses.MISSING or obj == MISSING
+
+
 def get_parsed_attr(
     params: Tuple[Union["DataclassBase", Namespace], ...],
     attribute_name: Text,
@@ -43,12 +49,12 @@ def get_parsed_attr(
 
 def get_params_item(
     params: Tuple[Union["DataclassBase", Namespace], ...],
-    params_type: Type[T],
+    params_type: Type[ParamsType],
     default: Optional[Any] = None,
-) -> Optional[T]:
+) -> Optional[ParamsType]:
     for args in params:
         if isinstance(args, params_type):
-            return args
+            return typing.cast(ParamsType, args)
     return default
 
 
@@ -172,7 +178,11 @@ class DataclassArgumentParser(ArgumentParser):
             for primitive_type in (int, float, str):
                 if not is_optional_type(field_type):
                     continue
+
+                # get container generic type
                 container_type = get_args(field_type)[0]
+                container_type = typing.cast(Type[Any], container_type)
+
                 for collection_type in (List,):
                     if container_type == collection_type[primitive_type]:
                         field_type = collection_type[primitive_type]
@@ -181,7 +191,8 @@ class DataclassArgumentParser(ArgumentParser):
 
             # unpack optional container
             if is_optional_type(field_type):
-                field_type: Type[Any] = get_args(field_type)[0]
+                optional_type = get_args(field_type)[0]
+                field_type = typing.cast(Type[Any], optional_type)
 
             # raise value errors for unsupported field types
             if is_union_type(field_type):
@@ -191,9 +202,10 @@ class DataclassArgumentParser(ArgumentParser):
 
             # parse supported fields
             if is_enum_type(field_type):
-                kwargs["choices"] = list(field_type)  # type: ignore
+                choices = typing.cast(Type[Enum], field_type)
+                kwargs["choices"] = list(choices)
                 kwargs["type"] = field_type
-                if field_obj.default is not dataclasses.MISSING:
+                if not is_missing(field_obj.default):
                     kwargs["default"] = field_obj.default
                 else:
                     kwargs["required"] = True
@@ -206,13 +218,13 @@ class DataclassArgumentParser(ArgumentParser):
 
                 kwargs["choices"] = choices
                 kwargs["type"] = field_types.pop()
-                if field_obj.default is not dataclasses.MISSING:
+                if not is_missing(field_obj.default):
                     kwargs["default"] = field_obj.default
                 else:
                     kwargs["required"] = True
             elif field_type is bool:
                 kwargs["type"] = str2bool
-                if field_obj.default is not dataclasses.MISSING:
+                if not is_missing(field_obj.default):
                     kwargs["default"] = field_obj.default
                 else:
                     kwargs["required"] = True
@@ -224,17 +236,17 @@ class DataclassArgumentParser(ArgumentParser):
 
                 kwargs["nargs"] = "+"
                 kwargs["type"] = container_types[0]
-                if field_obj.default is not dataclasses.MISSING:
+                if not is_missing(field_obj.default):
                     kwargs["default"] = field_obj.default
-                elif field_obj.default_factory is not dataclasses.MISSING:
+                elif not is_missing(field_obj.default_factory):
                     kwargs["default"] = field_obj.default_factory()
                 else:
                     kwargs["required"] = True
             else:
                 kwargs["type"] = field_type
-                if field_obj.default is not dataclasses.MISSING:
+                if not is_missing(field_obj.default):
                     kwargs["default"] = field_obj.default
-                elif field_obj.default_factory is not dataclasses.MISSING:
+                elif not is_missing(field_obj.default_factory):
                     kwargs["default"] = field_obj.default_factory()
                 else:
                     kwargs["required"] = True
