@@ -6,7 +6,7 @@ from pathlib import Path
 from typing import Any, Dict, List, Optional, Text, Type, Union
 
 from datasets import Dataset, DatasetDict, load_dataset
-from formerbox.common.dataclass_argparse import DataclassBase
+from formerbox.common.dataclass_argparse import MISSING, DataclassBase
 from formerbox.common.has_params import HasParsableParams, ParamsType
 from formerbox.common.registrable import Registrable
 from formerbox.utils import append_path_suffix, lazy_groups_of
@@ -71,11 +71,11 @@ class DatasetConverter(Registrable, HasParsableParams[ParamsType], metaclass=ABC
         raise NotImplementedError()
 
 
-@DatasetConverter.register("transformer-converter", constructor="from_partial")
-class TransformerDatasetConverter(DatasetConverter, DatasetProcessingMixin):
+class DatasetConverterBase(DatasetConverter, DatasetProcessingMixin, metaclass=ABCMeta):
     @dataclass
     class Params(DataclassBase):
         script_path: Text = field(
+            default=MISSING,
             metadata={
                 "help": "The path to the dataset processing script with the dataset builder."
                 " Can be either: \n"
@@ -83,14 +83,63 @@ class TransformerDatasetConverter(DatasetConverter, DatasetProcessingMixin):
                 " (if the script has the same name as the directory)\n"
                 " * a dataset identifier on HuggingFace AWS bucket (list all available"
                 " datasets and ids with datasets.list_datasets())."
-            }
-        )
-        output_path: Text = field(
-            metadata={"help": "The output directory to save converted text datasets."}
+            },
         )
         data_files: List[Text] = field(
-            metadata={"help": "Defining the data_files of the dataset configuration"}
+            default_factory=MISSING,
+            metadata={"help": "Defining the data_files of the dataset configuration"},
         )
+        output_path: Text = field(
+            default=MISSING,
+            metadata={"help": "The output directory to save converted text datasets."},
+        )
+        batched: bool = field(
+            default=True,
+            metadata={
+                "help": "Whether or not to provide batches of examples to the function."
+                " Default is set to `True`."
+            },
+        )
+        batch_size: int = field(
+            default=128,
+            metadata={
+                "help": "The number of examples per batch provided to function"
+                " if batched=True batch_size <= 0 or batch_size == None:"
+                " Provide the full dataset as a single batch to function."
+                " Default is set to `128`."
+            },
+        )
+        num_proc: int = field(
+            default=1,
+            metadata={
+                "help": "The number of processes for multiprocessing."
+                " Default is set to `1`."
+            },
+        )
+
+    def lookup_data_files(self, data_files: List[Text]) -> List[Text]:
+        assert data_files
+        if len(data_files) > 1:
+            return data_files
+
+        search_pattern = data_files[0]
+        search_results = glob(search_pattern)
+        if search_results:
+            logger.info(
+                "Found %d files using the pattern: %s",
+                len(search_results),
+                search_pattern,
+            )
+
+            data_files = search_results
+
+        return data_files
+
+
+@DatasetConverter.register("default", constructor="from_partial")
+class DefaultDatasetConverter(DatasetConverterBase):
+    @dataclass
+    class Params(DatasetConverterBase.Params):
         train_test_split: bool = field(
             default=False,
             metadata={
@@ -119,29 +168,6 @@ class TransformerDatasetConverter(DatasetConverter, DatasetProcessingMixin):
                 " Default is set to `0.1`."
             },
         )
-        batched: bool = field(
-            default=True,
-            metadata={
-                "help": "Whether or not to provide batches of examples to the function."
-                " Default is set to `True`."
-            },
-        )
-        batch_size: int = field(
-            default=128,
-            metadata={
-                "help": "The number of examples per batch provided to function"
-                " if batched=True batch_size <= 0 or batch_size == None:"
-                " Provide the full dataset as a single batch to function."
-                " Default is set to `128`."
-            },
-        )
-        num_proc: int = field(
-            default=1,
-            metadata={
-                "help": "The number of processes for multiprocessing."
-                " Default is set to `1`."
-            },
-        )
 
     params: Params
     params_type: Type[Params] = Params
@@ -153,7 +179,7 @@ class TransformerDatasetConverter(DatasetConverter, DatasetProcessingMixin):
         del args, kwargs  # use only designated args
         # search data_files if a user specified a pattern to use
         # otherwise the method will return the input values
-        data_files = self.search_data_files(self.params.data_files)
+        data_files = self.lookup_data_files(self.params.data_files)
         # prepare the output dir for writing results
         Path(self.params.output_path).parent.mkdir(exist_ok=True)
 
@@ -192,6 +218,7 @@ class TransformerDatasetConverter(DatasetConverter, DatasetProcessingMixin):
                     test_size=self.params.valid_size
                 )
 
+                assert isinstance(dataset_split, DatasetDict)
                 train_dataset, valid_dataset = dataset_split.values()
                 valid_path = append_path_suffix(self.params.output_path, ".valid")
                 self.save_dataset(valid_dataset, valid_path)
@@ -202,6 +229,7 @@ class TransformerDatasetConverter(DatasetConverter, DatasetProcessingMixin):
                     test_size=self.params.test_size
                 )
 
+                assert isinstance(dataset_split, DatasetDict)
                 train_dataset, test_dataset = dataset_split.values()
                 test_path = append_path_suffix(self.params.output_path, ".test")
                 self.save_dataset(test_dataset, test_path)
@@ -233,21 +261,3 @@ class TransformerDatasetConverter(DatasetConverter, DatasetProcessingMixin):
     def preprocess_text(self, text: Text) -> Instance:
         # workaround to avoid disambiguation in parsing text datasets
         return text.replace("\b", "\r")
-
-    def search_data_files(self, data_files: List[Text]) -> List[Text]:
-        assert data_files
-        if len(data_files) > 1:
-            return data_files
-
-        search_pattern = data_files[0]
-        search_results = glob(search_pattern)
-        if search_results:
-            logger.info(
-                "Found %d files using the pattern: %s",
-                len(search_results),
-                search_pattern,
-            )
-
-            data_files = search_results
-
-        return data_files
