@@ -13,12 +13,11 @@ import torch
 from formerbox.utils import all_subclasses, path_to_posix
 from numpy import float32, float64, int8, int16, int32, int64, uint8, uint16
 from torch.utils.data import Dataset
-from typing_extensions import Protocol
 
 logger = logging.getLogger(__name__)
 
 
-element_codes = {
+element_codes: Dict[int, Any] = {
     1: uint8,
     2: int8,
     3: int16,
@@ -55,11 +54,7 @@ def make_data_filepath(prefix_path: Text) -> Text:
     return prefix_path + ".bin"
 
 
-class MagicDecodable(Protocol):
-    magic_code: bytes
-
-
-class IndexedDatasetBase(Dataset, MagicDecodable, metaclass=ABCMeta):
+class IndexedDatasetBase(Dataset, metaclass=ABCMeta):
     """A base class for loading preprocessed binary datasets.
     Binary datasets are represented as 2 files (.bin, .idx),
     containing the data sequences (.bin) and indices (.idx).
@@ -78,6 +73,8 @@ class IndexedDatasetBase(Dataset, MagicDecodable, metaclass=ABCMeta):
             written to the index (.idx) file.
     """
 
+    magic_code: bytes = NotImplemented
+
     def __init__(self, filepath_prefix: Text, **kwargs: Any) -> None:
         # properties for reading data from files
         self.dtype: Optional[Type[np.dtype]] = None
@@ -114,7 +111,11 @@ class IndexedDatasetBase(Dataset, MagicDecodable, metaclass=ABCMeta):
             raise IndexError(f"Index({index}) is out of bounds")
 
     @staticmethod
-    def from_file(filepath_prefix: Union[Text, Path]) -> "IndexedDatasetBase":
+    def from_file(
+        filepath_prefix: Union[Text, Path], **kwargs: Any
+    ) -> "IndexedDatasetBase":
+        del kwargs  # support overrides
+
         filepath_prefix = path_to_posix(filepath_prefix)
         index_filepath = make_index_filepath(filepath_prefix)
         dataset: Optional[IndexedDatasetBase] = None
@@ -391,7 +392,7 @@ class IndexedDatasetBuilder(IndexedDatasetBuilderBase):
 
         # merge `sizes` lists
         if indexed_dataset.sizes is not None:
-            self.sizes.extend(indexed_dataset.sizes)
+            self.sizes.extend(indexed_dataset.sizes.tolist())
 
         # merge `dim_offsets` lists
         start_offset = self.dim_offsets[-1]
