@@ -2,7 +2,6 @@ from typing import Any, Optional
 
 import torch
 from pytorch_lightning.metrics import Metric
-from torch.nn import CrossEntropyLoss
 
 
 # pylint: disable=arguments-differ
@@ -11,20 +10,20 @@ class Perplexity(Metric):
 
     def __init__(
         self,
-        vocab_size: int,
         compute_on_step: bool = True,
         ddp_sync_on_step: bool = False,
         process_group: Optional[Any] = None,
     ) -> None:
         super().__init__(compute_on_step, ddp_sync_on_step, process_group)
-        self.vocab_size = vocab_size
-        self.criterion = CrossEntropyLoss()
-        self.add_state("loss", default=torch.tensor(0), dist_reduce_fx="sum")
 
-    def update(self, logits: torch.Tensor, labels: torch.Tensor) -> None:
-        logits = logits.view(-1, self.vocab_size)
-        labels = labels.view(-1)
-        loss = self.criterion(logits.float(), labels.long())
+        self.add_state(
+            name="loss",
+            default=torch.tensor(0),
+            dist_reduce_fx="sum",
+            persistent=False,
+        )
+
+    def update(self, loss: torch.Tensor) -> None:
         self.loss = self.loss + loss
 
     def compute(self) -> torch.Tensor:
