@@ -1,4 +1,4 @@
-from .utils import (
+from formerbox.utils.utils import (
     all_subclasses,
     append_path_suffix,
     init_from_args,
@@ -8,4 +8,5 @@ from .utils import (
     path_to_posix,
     perplexity,
     str2bool,
+    update_left_inplace,
 )
